@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,15 +19,17 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef ECHO_MESSAGE_SOURCE
 #define ECHO_MESSAGE_SOURCE
-
+#ifndef _MSC_VER
 #include <unistd.h>
-
+#endif
+#include "../../executor/commander/basic/echo_message_commander.c"
+#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
 #include "../../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 #include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
@@ -36,17 +38,6 @@
 #include "../../executor/accessor/knowledge_getter/knowledge_part_getter.c"
 #include "../../logger/logger.c"
 
-
-#ifdef GNU_LINUX_OPERATING_SYSTEM
-    #include "../../executor/commander/unix_commander/echo_message_unix_commander.c"
-    #include "../../constant/model/command/unix_command_model.c"
-#endif
-
-#ifdef WIN32
-    #include "../../executor/commander/windows_commander/echo_message_windows_commander.c"
-    #include "../../constant/model/command/win32_command_model.c"
-#endif
-
 /**
  * Echos the message to standard output.
  *
@@ -82,14 +73,9 @@ void apply_echo_message(void* p0, void* p1, void* p2) {
     // Get message part model item data and count.
     copy_array_forward((void*) &mmd, mm, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
     copy_array_forward((void*) &mmc, mm, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) COUNT_ITEM_STATE_CYBOI_NAME);
+   
+    echo_message_commander(mmd, mmc);
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
-    echo_message_unix_commander(mmd, mmc);
-#endif
-
-#ifdef WIN32
-    echo_message_windows_commander(mmd, mmc);
-#endif
 }
 
 /* ECHO_MESSAGE_SOURCE */
