@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,34 +19,27 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef REMOVE_FILE_SOURCE
 #define REMOVE_FILE_SOURCE
 
+#ifndef _MSC_VER
 #include <unistd.h>
+#endif
 
 #include "../../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 #include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
 #include "../../constant/name/cybol/logic/commander/remove_file_commander_logic_cybol_name.c"
 #include "../../constant/type/cyboi/state_cyboi_type.c"
+#include "../../executor/commander/basic/remove_file_commander.c"
 #include "../../executor/accessor/knowledge_getter/knowledge_part_getter.c"
 #include "../../logger/logger.c"
 
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
-    #include "../../executor/commander/unix_commander/remove_file_unix_commander.c"
-    #include "../../constant/model/command/unix_command_model.c"
-#endif
-
-#ifdef WIN32
-    #include "../../executor/commander/windows_commander/remove_file_windows_commander.c"
-    #include "../../constant/model/command/win32_command_model.c"
-#endif
-
 /**
  * Removing files and directories from a path.
  *
@@ -137,14 +130,7 @@ void apply_remove_file(void* p0, void* p1, void* p2) {
     // Get verbal part model item data.
     copy_array_forward((void*) &vmd, vm, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
 
-
-#ifdef GNU_LINUX_OPERATING_SYSTEM
-    remove_file_unix_commander(pmd, pmc, fmd, imd, rmd, vmd);
-#endif
-
-#ifdef WIN32
-    remove_file_windows_commander(pmd, pmc, fmd, imd, rmd);
-#endif
+    remove_file_commander(pmd, pmc, fmd, imd, rmd, vmd);
 }
 
 /* REMOVE_FILE_SOURCE */
