@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,15 +19,16 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef TAPE_ARCHIVER_SOURCE
 #define TAPE_ARCHIVER_SOURCE
-
+#ifndef _MSC_VER
 #include <unistd.h>
-
+#endif
+#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
 #include "../../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 #include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
@@ -36,19 +37,20 @@
 #include "../../executor/accessor/knowledge_getter/knowledge_part_getter.c"
 #include "../../logger/logger.c"
 
+#include "../../executor/commander/basic/tape_archiver_commander.c"
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
-    #include "../../executor/commander/unix_commander/tape_archiver_unix_commander.c"
+#ifdef __APPLE__
+    #include "../../constant/model/command/unix_command_model.c"
+#elif WIN32    
+    #include "../../constant/model/command/win32_command_model.c"
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include "../../constant/model/command/unix_command_model.c"
+#else
     #include "../../constant/model/command/unix_command_model.c"
 #endif
 
-#ifdef WIN32
-    #include "../../executor/commander/windows_commander/tape_archiver_windows_commander.c"
-    #include "../../constant/model/command/win32_command_model.c"
-#endif
-
 /**
- * Packs/Unpacks a directory or file 
+ * Packs/Unpacks a directory or file
  *
  * Expected parametres:
  * - source (required): the source for archiving
@@ -66,7 +68,7 @@
  */
 void apply_tape_archiver(void* p0, void* p1, void* p2) {
 
-    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Apply copy file.");
+    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Apply tape archiver file.");
 
     // The source part.
     void* s = *NULL_POINTER_STATE_CYBOI_MODEL;
@@ -154,15 +156,9 @@ void apply_tape_archiver(void* p0, void* p1, void* p2) {
     copy_array_forward((void*) &umd, um, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
     // Get verbal part model item data.
     copy_array_forward((void*) &vmd, vm, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
-
-
-#ifdef GNU_LINUX_OPERATING_SYSTEM
-    tape_archiver_unix_commander(smd, smc, dmd, dmc, fmd, gmd, umd, vmd);
-#endif
-
-#ifdef WIN32
-    tape_archiver_windows_commander(smd, smc, dmd, dmc, fmd, gmd, umd, vmd);
-#endif
+    
+    tape_archiver_commander(smd, smc, dmd, dmc, fmd, gmd, umd, vmd);
+    
 }
 /* TAPE_ARCHIVER_SOURCE */
 #endif
