@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -31,28 +31,23 @@
 #include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 
 /** The "off" log level option cyboi model. */
-static wchar_t OFF_LOG_LEVEL_OPTION_CYBOI_MODEL_ARRAY[] = {L'o', L'f', L'f'};
-static wchar_t* OFF_LOG_LEVEL_OPTION_CYBOI_MODEL = OFF_LOG_LEVEL_OPTION_CYBOI_MODEL_ARRAY;
+static wchar_t* OFF_LOG_LEVEL_OPTION_CYBOI_MODEL = L"off";
 static int* OFF_LOG_LEVEL_OPTION_CYBOI_MODEL_COUNT = NUMBER_3_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The "error" log level option cyboi model. */
-static wchar_t ERROR_LOG_LEVEL_OPTION_CYBOI_MODEL_ARRAY[] = {L'e', L'r', L'r', L'o', L'r'};
-static wchar_t* ERROR_LOG_LEVEL_OPTION_CYBOI_MODEL = ERROR_LOG_LEVEL_OPTION_CYBOI_MODEL_ARRAY;
+static wchar_t* ERROR_LOG_LEVEL_OPTION_CYBOI_MODEL = L"error";
 static int* ERROR_LOG_LEVEL_OPTION_CYBOI_MODEL_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The "warning" log level option cyboi model. */
-static wchar_t WARNING_LOG_LEVEL_OPTION_CYBOI_MODEL_ARRAY[] = {L'w', L'a', L'r', L'n', L'i', L'n', L'g'};
-static wchar_t* WARNING_LOG_LEVEL_OPTION_CYBOI_MODEL = WARNING_LOG_LEVEL_OPTION_CYBOI_MODEL_ARRAY;
+static wchar_t* WARNING_LOG_LEVEL_OPTION_CYBOI_MODEL = L"warning";
 static int* WARNING_LOG_LEVEL_OPTION_CYBOI_MODEL_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The "information" log level option cyboi model. */
-static wchar_t INFORMATION_LOG_LEVEL_OPTION_CYBOI_MODEL_ARRAY[] = {L'i', L'n', L'f', L'o', L'r', L'm', L'a', L't', L'i', L'o', L'n'};
-static wchar_t* INFORMATION_LOG_LEVEL_OPTION_CYBOI_MODEL = INFORMATION_LOG_LEVEL_OPTION_CYBOI_MODEL_ARRAY;
+static wchar_t* INFORMATION_LOG_LEVEL_OPTION_CYBOI_MODEL = L"information";
 static int* INFORMATION_LOG_LEVEL_OPTION_CYBOI_MODEL_COUNT = NUMBER_11_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The "debug" log level option cyboi model. */
-static wchar_t DEBUG_LOG_LEVEL_OPTION_CYBOI_MODEL_ARRAY[] = {L'd', L'e', L'b', L'u', L'g'};
-static wchar_t* DEBUG_LOG_LEVEL_OPTION_CYBOI_MODEL = DEBUG_LOG_LEVEL_OPTION_CYBOI_MODEL_ARRAY;
+static wchar_t* DEBUG_LOG_LEVEL_OPTION_CYBOI_MODEL = L"debug";
 static int* DEBUG_LOG_LEVEL_OPTION_CYBOI_MODEL_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /* LOG_LEVEL_OPTION_CYBOI_MODEL_CONSTANT_SOURCE */
