@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -30,5 +30,9 @@
 static int NUMBER_MINUS_1_INTEGER_STATE_CYBOI_MODEL_ARRAY[] = {-1};
 static int* NUMBER_MINUS_1_INTEGER_STATE_CYBOI_MODEL = NUMBER_MINUS_1_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
+/** The number -2 integer state cyboi model. */
+static int NUMBER_MINUS_2_INTEGER_STATE_CYBOI_MODEL_ARRAY[] = {-2};
+static int* NUMBER_MINUS_2_INTEGER_STATE_CYBOI_MODEL = NUMBER_MINUS_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
 /* NEGATIVE_INTEGER_STATE_CYBOI_MODEL_CONSTANT_SOURCE */
 #endif
