@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -35,6 +35,11 @@ static wchar_t ALL_LIST_DIRECTORY_CONTENTS_UNIX_COMMAND_OPTION_NAME_ARRAY[] = {L
 static wchar_t* ALL_LIST_DIRECTORY_CONTENTS_UNIX_COMMAND_OPTION_NAME = ALL_LIST_DIRECTORY_CONTENTS_UNIX_COMMAND_OPTION_NAME_ARRAY;
 static int* ALL_LIST_DIRECTORY_CONTENTS_UNIX_COMMAND_OPTION_NAME_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
+/** The almost-all list unix command option name. */
+static wchar_t ALMOST_ALL_LIST_DIRECTORY_CONTENTS_UNIX_COMMAND_OPTION_NAME_ARRAY[] = {L'-', L'-', L'a', L'l', L'm', L'o', L's', L't', L'-', L'a', L'l', L'l'};
+static wchar_t* ALMOST_ALL_LIST_DIRECTORY_CONTENTS_UNIX_COMMAND_OPTION_NAME = ALMOST_ALL_LIST_DIRECTORY_CONTENTS_UNIX_COMMAND_OPTION_NAME_ARRAY;
+static int* ALMOST_ALL_LIST_DIRECTORY_CONTENTS_UNIX_COMMAND_OPTION_NAME_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
 /** The long list unix command option name. */
 static wchar_t LONG_LIST_DIRECTORY_CONTENTS_UNIX_COMMAND_OPTION_NAME_ARRAY[] = {L'-', L'l'};
 static wchar_t* LONG_LIST_DIRECTORY_CONTENTS_UNIX_COMMAND_OPTION_NAME = LONG_LIST_DIRECTORY_CONTENTS_UNIX_COMMAND_OPTION_NAME_ARRAY;
