@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -30,20 +30,20 @@
 
 #include "../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 
-/** The input 1 logic logic cybol name. */
-static wchar_t INPUT_1_LOGIC_LOGIC_CYBOL_NAME_ARRAY[] = {L'i', L'n', L'p', L'u', L't', L'_', L'1'};
-static wchar_t* INPUT_1_LOGIC_LOGIC_CYBOL_NAME = INPUT_1_LOGIC_LOGIC_CYBOL_NAME_ARRAY;
-static int* INPUT_1_LOGIC_LOGIC_CYBOL_NAME_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The input 2 logic logic cybol name. */
-static wchar_t INPUT_2_LOGIC_LOGIC_CYBOL_NAME_ARRAY[] = {L'i', L'n', L'p', L'u', L't', L'_', L'2'};
-static wchar_t* INPUT_2_LOGIC_LOGIC_CYBOL_NAME = INPUT_2_LOGIC_LOGIC_CYBOL_NAME_ARRAY;
-static int* INPUT_2_LOGIC_LOGIC_CYBOL_NAME_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+/** The input logic logic cybol name. */
+static wchar_t INPUT_LOGIC_LOGIC_CYBOL_NAME_ARRAY[] = {L'i', L'n', L'p', L'u', L't'};
+static wchar_t* INPUT_LOGIC_LOGIC_CYBOL_NAME = INPUT_LOGIC_LOGIC_CYBOL_NAME_ARRAY;
+static int* INPUT_LOGIC_LOGIC_CYBOL_NAME_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The output logic logic cybol name. */
 static wchar_t OUTPUT_LOGIC_LOGIC_CYBOL_NAME_ARRAY[] = {L'o', L'u', L't', L'p', L'u', L't'};
 static wchar_t* OUTPUT_LOGIC_LOGIC_CYBOL_NAME = OUTPUT_LOGIC_LOGIC_CYBOL_NAME_ARRAY;
 static int* OUTPUT_LOGIC_LOGIC_CYBOL_NAME_COUNT = NUMBER_6_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
+/** The type logic logic cybol name. */
+static wchar_t TYPE_LOGIC_LOGIC_CYBOL_NAME_ARRAY[] = {L't', L'y', L'p', L'e'};
+static wchar_t* TYPE_LOGIC_LOGIC_CYBOL_NAME = TYPE_LOGIC_LOGIC_CYBOL_NAME_ARRAY;
+static int* TYPE_LOGIC_LOGIC_CYBOL_NAME_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
 /* LOGIC_LOGIC_CYBOL_NAME_CONSTANT_SOURCE */
 #endif
