@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -119,11 +119,11 @@ void check_wait(void* p0, void* p1) {
     }
 
 /*??
-fwprintf(stdout, L"TEST wait *cyboi_service_irq: %i\n", *((int*) c));
-fwprintf(stdout, L"TEST wait *display_irq: %i\n", *((int*) d));
-fwprintf(stdout, L"TEST wait *serial_port_irq: %i\n", *((int*) s));
-fwprintf(stdout, L"TEST wait *terminal_irq: %i\n", *((int*) t));
-fwprintf(stdout, L"TEST wait *www_service_irq: %i\n", *((int*) w));
+fwprintf(stdout, L"TEST wait *cyboi_service_irq: %i\n", *((int*) ci));
+fwprintf(stdout, L"TEST wait *display_irq: %i\n", *((int*) di));
+fwprintf(stdout, L"TEST wait *serial_port_irq: %i\n", *((int*) si));
+fwprintf(stdout, L"TEST wait *terminal_irq: %i\n", *((int*) ti));
+fwprintf(stdout, L"TEST wait *www_service_irq: %i\n", *((int*) wi));
 */
 
     // The sleep loop above is left as soon as at least one of the
