@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -46,6 +46,21 @@
 #include "../variable/log_setting.c"
 #include "../variable/reference_counter.c"
 
+#ifdef _MSC_VER          // see: http://msdn.microsoft.com/de-de/library/b0084kay.aspx
+
+    #if (_MSC_VER < 1800) // Check Visual Studio version, C99 is not supported in versions below VS2013
+        #error Visual Studio 2013 or higher is required for successful build of this application
+    #endif
+
+    #define PTW32_STATIC_LIB //use pthread.lib built with static linking see http://www.technologische-hilfe.de/antworten/pthreads-win32-statisch-linken-support-230866062.html
+    //#define WIN32_LEAN_AND_MEAN // avoids compiler errors in VS related to duplicate definitions from includes in windows.h and winsock2.h, see http://www.gamedev.net/topic/127476-define-win32_lean_and_mean/
+    //#define _TM_DEFINED // avoids redeclaration of time_t in glibc time.h
+    //#define _TIMESPEC_DEFINED; // avoids redeclaration of timespec in pthread.h
+    #define _CRT_NONSTDC_NO_DEPRECATE //avoids errors related to deprecated CRT functions see http://msdn.microsoft.com/de-de/library/ms235384(v=vs.90).aspx
+    #define _CRT_SECURE_NO_WARNINGS //allows use of unsecure functions see http://msdn.microsoft.com/de-de/library/8ef0s5kh.aspx
+    #define _USE_MATH_DEFINES
+#endif
+
 /**
  * The main entry function.
  *
@@ -66,6 +81,13 @@
  */
 int main(int p0, char** p1) {
 
+#ifdef _MSC_VER
+    #ifdef PTW32_STATIC_LIB
+        pthread_win32_process_attach_np(); // see README.NONPORTABLE in pthread source directory
+        pthread_win32_thread_attach_np(); // Currently a no-op
+    #endif
+#endif
+
     //
     // One note about dynamic memory allocation:
     // There is no point in freeing blocks at the end of an application programme,
@@ -77,10 +99,7 @@ int main(int p0, char** p1) {
     // it will not harm the operating system, as the memory occupied by
     // the application will be freed automatically on process shutdown.
     //
-
-    //
-    //?? TODO: YET TO ANSWER: How is that with forgotten threads?
-    //?? Are they killed automatically when a process is shut down?
+    // Presumably, forgotten threads are killed automatically, too.
     //
 
     // Return 1 to indicate an error, by default.
@@ -165,6 +184,8 @@ fwprintf(stdout, L"TEST PART_REFERENCE_COUNTER BEGIN: %i\n", *PART_REFERENCE_COU
         int m = *HELP_OPERATION_MODE_CYBOI_MODEL;
         // The cybol knowledge file path item.
         void* k = *NULL_POINTER_STATE_CYBOI_MODEL;
+        // The test unit.
+        int t = *NUMBER_MINUS_1_INTEGER_STATE_CYBOI_MODEL;
 
         // Allocate cybol knowledge file path item.
         // CAUTION! Due to memory allocation handling, the size MUST NOT
@@ -172,7 +193,7 @@ fwprintf(stdout, L"TEST PART_REFERENCE_COUNTER BEGIN: %i\n", *PART_REFERENCE_COU
         allocate_item((void*) &k, (void*) NUMBER_1_INTEGER_STATE_CYBOI_MODEL, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
 
         // Optionalise command line argument options.
-        optionalise((void*) &m, k, (void*) LOG_LEVEL, (void*) LOG_OUTPUT, (void*) p1, (void*) &p0);
+        optionalise((void*) &m, k, (void*) LOG_LEVEL, (void*) &t, (void*) LOG_OUTPUT, (void*) p1, (void*) &p0);
 
         // Orient log output file stream.
         //
@@ -187,16 +208,18 @@ fwprintf(stdout, L"TEST PART_REFERENCE_COUNTER BEGIN: %i\n", *PART_REFERENCE_COU
 
         if (m == *VERSION_OPERATION_MODE_CYBOI_MODEL) {
 
+            // Print version information on screen.
             inform((void*) stdout);
 
         } else if (m == *HELP_OPERATION_MODE_CYBOI_MODEL) {
 
+            // Print help message on screen.
             help((void*) stdout);
 
         } else if (m == *TEST_OPERATION_MODE_CYBOI_MODEL) {
 
-            // Call test function.
-            test();
+            // Call test unit function.
+            test((void*) &t);
 
         } else if (m == *KNOWLEDGE_OPERATION_MODE_CYBOI_MODEL) {
 
@@ -236,6 +259,17 @@ fwprintf(stdout, L"TEST PART_REFERENCE_COUNTER END: %i\n", *PART_REFERENCE_COUNT
         log_write(stdout, L"Error: Could not execute cyboi. The command line argument vector is null.\n");
     }
 
+#ifdef _MSC_VER
+    #ifdef PTW32_STATIC_LIB
+        pthread_win32_process_detach_np();
+        pthread_win32_thread_detach_np();
+    #endif
+#endif
+
+#ifdef _DEBUG
+    getchar();
+#endif
+
     return r;
 }
 
