@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,13 +19,14 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef GLOBALISER_SOURCE
 #define GLOBALISER_SOURCE
 
+#include "../controller/globaliser/compound_globaliser.c"
 #include "../controller/globaliser/conversion_globaliser.c"
 #include "../controller/globaliser/display_globaliser.c"
 #include "../controller/globaliser/integral_globaliser.c"
@@ -104,6 +105,15 @@ void globalise() {
     globalise_socket();
     globalise_thread();
     globalise_thread_identification();
+
+    //
+    // CAUTION! The order of above function calls is arbitrary,
+    // since most use the "sizeof" function and are independent
+    // from each other.
+    // However, the "globalise_compound" function depends upon
+    // other type sizes, so that it can only be called as LAST.
+    //
+    globalise_compound();
 }
 
 /* GLOBALISER_SOURCE */
