@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,14 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef DISPLAY_GLOBALISER_SOURCE
 #define DISPLAY_GLOBALISER_SOURCE
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#ifdef __APPLE__
+    //?? Add Cocoa support
+#elif WIN32
+    //?? Add WIN32 support
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include "../../controller/globaliser/x_window_system_globaliser.c"
+#else
     #include "../../controller/globaliser/x_window_system_globaliser.c"
 #endif
 
@@ -35,7 +41,13 @@
  */
 void globalise_display() {
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#ifdef __APPLE__
+    //?? Add Cocoa support
+#elif WIN32
+    //?? Add WIN32 support
+#elif GNU_LINUX_OPERATING_SYSTEM
+    globalise_x_window_system();
+#else
     globalise_x_window_system();
 #endif
 }
