@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,11 +27,15 @@
 #define PROCESS_GLOBALISER_SOURCE
 
 #include <sys/types.h>
-#include <unistd.h>
-
 #include "../../variable/type_size/integral_type_size.c"
 #include "../../variable/type_size/process_type_size.c"
 
+#ifdef _MSC_VER
+#include "../../windows/cyboi_win_mapper.h"
+#else
+#include <unistd.h>
+#endif
+
 /**
  * Initialises process global variables.
  */
