@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,12 +27,28 @@
 #define SOCKET_GLOBALISER_SOURCE
 
 #ifdef WIN32
+#ifndef _MSC_VER
+#define INCLUDE_WINSOCK2
+#endif
+#endif
+
+#ifdef WIN32_LEAN_AND_MEAN
+#ifdef _MSC_VER
+#define INCLUDE_WINSOCK2
+#endif
+#endif
+
+#ifdef WIN32
+#ifdef INCLUDE_WINSOCK2
     #include <winsock2.h>
+#endif
 #else
     #include <arpa/inet.h>
     #include <netinet/in.h>
     #include <sys/un.h>
 #endif
+
+
 #include <sys/stat.h>
 
 #include "../../variable/type_size/integral_type_size.c"
