@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -166,7 +166,7 @@ fwprintf(stdout, L"TEST handle NULL fd: %i\n", fd);
             // This is IMPORTANT since otherwise, the original data position
             // gets increased and the count remaining decreased to zero,
             // so that knowledge access works only once, but not anymore afterwards.
-            deserialise_knowledge((void*) &ref, p2, (void*) &pathd, (void*) &pathc);
+            deserialise_knowledge((void*) &ref, p2, (void*) &pathd, (void*) &pathc, p2);
 
             // Get reference signal part model item.
             copy_array_forward((void*) &refm, ref, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) MODEL_PART_STATE_CYBOI_NAME);
@@ -186,7 +186,7 @@ fwprintf(stdout, L"TEST handle NULL fd: %i\n", fd);
             // This is IMPORTANT since otherwise, the original data position
             // gets increased and the count remaining decreased to zero,
             // so that knowledge access works only once, but not anymore afterwards.
-            deserialise_knowledge((void*) &part, p2, (void*) &pathd, (void*) &pathc);
+            deserialise_knowledge((void*) &part, p2, (void*) &pathd, (void*) &pathc, p2);
 
             // Handle signal.
             handle(part, p1, p2, p3, p4, p5);
@@ -213,7 +213,7 @@ fwprintf(stdout, L"TEST handle NULL fd: %i\n", fd);
             // This is IMPORTANT since otherwise, the original data position
             // gets increased and the count remaining decreased to zero,
             // so that knowledge access works only once, but not anymore afterwards.
-            deserialise_knowledge((void*) &part, p2, (void*) &pathd, (void*) &pathc);
+            deserialise_knowledge((void*) &part, p2, (void*) &pathd, (void*) &pathc, p2);
 
             // Handle signal.
             handle(part, p1, p2, p3, p4, p5);
