@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,13 +19,14 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef UNGLOBALISER_SOURCE
 #define UNGLOBALISER_SOURCE
 
+#include "../controller/unglobaliser/compound_unglobaliser.c"
 #include "../controller/unglobaliser/conversion_unglobaliser.c"
 #include "../controller/unglobaliser/display_unglobaliser.c"
 #include "../controller/unglobaliser/integral_unglobaliser.c"
@@ -52,6 +53,7 @@ void unglobalise() {
     // Instead, use malloc, free and similar functions directly!
     //
 
+    unglobalise_compound();
     unglobalise_conversion();
     unglobalise_display();
     unglobalise_integral();
