@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -34,27 +34,36 @@
 /**
  * Calculates the difference between two pointers.
  *
- * @param p0 the difference, which is the minuend BEFORE the operation
- * @param p1 the subtrahend
+ * @param p0 the difference
+ * @param p1 the minuend
+ * @param p2 the subtrahend
  */
-void calculate_pointer_difference(void* p0, void* p1) {
+void calculate_pointer_difference(void* p0, void* p1, void* p2) {
 
-    if (p1 != *NULL_POINTER_STATE_CYBOI_MODEL) {
+    if (p2 != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
-        void* s = (void*) p1;
+        void** s = (void**) p2;
 
-        if (p0 != *NULL_POINTER_STATE_CYBOI_MODEL) {
+        if (p1 != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
-            void* d = (void*) p0;
+            void** m = (void**) p1;
 
-            log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Calculate pointer difference.");
+            if (p0 != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
-            //?? TODO: How to return a difference of type "int"
-            //?? if both of the given parametres are of type "void*"?
+                int* d = (int*) p0;
+
+                log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Calculate pointer difference.");
+
+                *d = *m - *s;
+
+            } else {
+
+                log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not calculate pointer difference. The difference is null.");
+            }
 
         } else {
 
-            log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not calculate pointer difference. The difference is null.");
+            log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not calculate pointer difference. The minuend is null.");
         }
 
     } else {
