@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -32,6 +32,7 @@
 #include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
 #include "../../../constant/type/cyboi/state_cyboi_type.c"
 #include "../../../executor/calculator/basic/character_calculator.c"
+#include "../../../executor/calculator/basic/complex_calculator.c"
 #include "../../../executor/calculator/basic/double_calculator.c"
 #include "../../../executor/calculator/basic/fraction_calculator.c"
 #include "../../../executor/calculator/basic/integer_calculator.c"
@@ -76,7 +77,6 @@ void calculate_item(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
  * @param p3 the operand type
  */
 void calculate_value(void* p0, void* p1, void* p2, void* p3) {
-
     log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Calculate value.");
 
     // The comparison result.
@@ -109,6 +109,17 @@ void calculate_value(void* p0, void* p1, void* p2, void* p3) {
             calculate_character(p0, p1, p2);
         }
     }
+    
+    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+    
+        compare_integer_equal((void*) &r, p3, (void*) COMPLEX_NUMBER_STATE_CYBOI_TYPE);
+
+        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+            calculate_complex(p0, p1, p2);
+        }
+    }
+    
 
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
@@ -195,7 +206,7 @@ void calculate_value(void* p0, void* p1, void* p2, void* p3) {
  * @param p4 the index
  */
 void calculate_value_offset(void* p0, void* p1, void* p2, void* p3, void* p4) {
-
+  
     log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Calculate value offset.");
 
     // The result value, operand value.
