@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -30,11 +30,14 @@
 #include "../../../../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../../../../logger/logger.c"
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
-    #include "../../../../executor/communicator/receiver/x_window_system/x_window_system_receiver.c"
-#endif
-#ifdef WIN32
+#ifdef __APPLE__
+    //?? Add Cocoa support
+#elif WIN32
     #include "../../../../executor/communicator/receiver/win32_display/win32_display_receiver.c"
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include "../../../../executor/communicator/receiver/x_window_system/x_window_system_receiver.c"
+#else
+    #include "../../../../executor/communicator/receiver/x_window_system/x_window_system_receiver.c"
 #endif
 
 /**
@@ -53,11 +56,14 @@ void receive_display(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Receive display.");
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
-    receive_x_window_system(p0, p1, p2, p3, p4, p5, p6, p7);
-#endif
-#ifdef WIN32
+#ifdef __APPLE__
+    //?? Add Cocoa support
+#elif WIN32
     receive_win32_display(p0, p1, p2, p3, p4, p5, p6, p7);
+#elif GNU_LINUX_OPERATING_SYSTEM
+    receive_x_window_system(p0, p1, p2, p3, p4, p5, p6, p7);
+#else
+    receive_x_window_system(p0, p1, p2, p3, p4, p5, p6, p7);
 #endif
 }
 
