@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -43,6 +43,11 @@
 #include "../../../../executor/modifier/overwriter/array_overwriter.c"
 #include "../../../../logger/logger.c"
 
+#ifdef _MSC_VER
+    #include <io.h>
+    #include "../../../../windows/cyboi_win_mapper.h"
+#endif
+
 /**
  * Receives a serial port character.
  *
@@ -146,14 +151,24 @@ void receive_serial_port_character(void* p0, void* p1, void* p2, void* p3, void*
 
                     // Get character from source input stream of serial port.
                     // ssize_t e = read(*f, (void*) c, ts);
+#ifdef __APPLE__
                     ssize_t e = read(*f, (void*) &c, ts);
+#elif WIN32
+                    int e = read(*f, (void*) &c, ts);
+#elif GNU_LINUX_OPERATING_SYSTEM
+                    ssize_t e = read(*f, (void*) &c, ts);
+#else
+                    ssize_t e = read(*f, (void*) &c, ts);
+#endif
 
                     // Unlock serial port mutex.
                     pthread_mutex_unlock(p2);
 
                     // The byte number as temporary "int" variable.
                     //
-                    // The "ssize_t" type is similar to "size_t".
+                    // The "ssize_t" type is signed and a glibc extension.
+                    // The similar "size_t" type, on the other hand, is unsigned.
+                    //
                     // On 64 Bit machines they might have a size of 8 Byte,
                     // whereas the "int" type has the usual size of 4 Byte.
                     // When trying to cast between the two, memory errors
