@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -136,7 +136,7 @@ void receive_win32_display_process(void* p0, void* p1, void* p2, void* p3, void*
             // Sent when a window is closed.
 
 //??            PostQuitMessage(*NUMBER_0_INTEGER_STATE_CYBOI_MODEL);
-            DestroyWindow(w);
+            DestroyWindow((HWND)w);
 
         } else if (t == WM_CREATE) {
 
