@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -31,8 +31,13 @@
 #include "../../../../executor/representer/serialiser.c"
 #include "../../../../logger/logger.c"
 
-#ifdef WIN32
+
+#ifdef __APPLE__
+    //?? Add cocoa support for Apple
+#elif WIN32
     #include "../../../../executor/communicator/sender/win32_display/win32_display_sender.c"
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include "../../../../executor/communicator/sender/x_window_system/x_window_system_sender.c"
 #else
     #include "../../../../executor/communicator/sender/x_window_system/x_window_system_sender.c"
 #endif
@@ -56,11 +61,16 @@ void send_display(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, vo
     // Serialise (draw) source onto window.
     serialise(*NULL_POINTER_STATE_CYBOI_MODEL, p0, p1, p2, p3, p4, p7, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, p5, *NULL_POINTER_STATE_CYBOI_MODEL, p6);
 
-#ifdef WIN32
+#ifdef __APPLE__
+    //?? Add cocoa support for Apple
+#elif WIN32
     send_win32_display(p7);
+#elif GNU_LINUX_OPERATING_SYSTEM
+    send_x_window_system(p7);
 #else
     send_x_window_system(p7);
 #endif
+
 }
 
 /* DISPLAY_SENDER_SOURCE */
