@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -73,16 +73,6 @@ void compare_character(void* p0, void* p1, void* p2, void* p3) {
             }
         }
 
-        if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-            if (*a == *SMALLER_COMPARE_LOGIC_CYBOI_FORMAT) {
-
-                r = *TRUE_BOOLEAN_STATE_CYBOI_MODEL;
-
-                compare_character_smaller(p0, p1, p2);
-            }
-        }
-
         if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
             if (*a == *GREATER_COMPARE_LOGIC_CYBOI_FORMAT) {
@@ -93,6 +83,26 @@ void compare_character(void* p0, void* p1, void* p2, void* p3) {
             }
         }
 
+        if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+            if (*a == *GREATER_OR_EQUAL_COMPARE_LOGIC_CYBOI_FORMAT) {
+
+                r = *TRUE_BOOLEAN_STATE_CYBOI_MODEL;
+
+                compare_character_greater_or_equal(p0, p1, p2);
+            }
+        }
+
+        if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+            if (*a == *SMALLER_COMPARE_LOGIC_CYBOI_FORMAT) {
+
+                r = *TRUE_BOOLEAN_STATE_CYBOI_MODEL;
+
+                compare_character_smaller(p0, p1, p2);
+            }
+        }
+
         if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
             if (*a == *SMALLER_OR_EQUAL_COMPARE_LOGIC_CYBOI_FORMAT) {
@@ -105,11 +115,11 @@ void compare_character(void* p0, void* p1, void* p2, void* p3) {
 
         if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-            if (*a == *GREATER_OR_EQUAL_COMPARE_LOGIC_CYBOI_FORMAT) {
+            if (*a == *UNEQUAL_COMPARE_LOGIC_CYBOI_FORMAT) {
 
                 r = *TRUE_BOOLEAN_STATE_CYBOI_MODEL;
 
-                compare_character_greater_or_equal(p0, p1, p2);
+                compare_character_unequal(p0, p1, p2);
             }
         }
 
