@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -284,14 +284,16 @@ void decode_utf_8(void* p0, void* p1, void* p2) {
                     // anonymous state only known to the function internally is used instead.
                     // It just indicates where conversion is started.
                     int n = -1;
-                    #ifdef WIN32
-                        int len = MultiByteToWideChar (65001, 0, (LPCSTR) sd, *sc, (LPWSTR) dd, 0);
-                        n =  MultiByteToWideChar (65001, 0, (LPCSTR) sd, *sc, (LPWSTR) dd, len);
-                    #endif
-                    #ifdef GNU_LINUX_OPERATING_SYSTEM
-                        n = mbsnrtowcs((wchar_t*) dd, (const char**) &sd, tsc, tds, (mbstate_t*) *NULL_POINTER_STATE_CYBOI_MODEL);
-                    #endif
-
+#ifdef __APPLE__
+                    n = mbsnrtowcs((wchar_t*) dd, (const char**) &sd, tsc, tds, (mbstate_t*) *NULL_POINTER_STATE_CYBOI_MODEL);
+#elif WIN32
+                    int len = MultiByteToWideChar (65001, 0, (LPCSTR) sd, *sc, (LPWSTR) dd, 0);
+                    n =  MultiByteToWideChar (65001, 0, (LPCSTR) sd, *sc, (LPWSTR) dd, len);
+#elif GNU_LINUX_OPERATING_SYSTEM
+                    n = mbsnrtowcs((wchar_t*) dd, (const char**) &sd, tsc, tds, (mbstate_t*) *NULL_POINTER_STATE_CYBOI_MODEL);
+#else
+                    n = mbsnrtowcs((wchar_t*) dd, (const char**) &sd, tsc, tds, (mbstate_t*) *NULL_POINTER_STATE_CYBOI_MODEL);
+#endif
 
                     if (n >= *NUMBER_0_INTEGER_STATE_CYBOI_MODEL) {
 
