@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -29,6 +29,9 @@
 #include <errno.h>
 #include <locale.h>
 #include <wchar.h>
+#ifdef WIN32
+    #include <windows.h>
+#endif
 
 #include "../../../../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
@@ -166,7 +169,7 @@
 //
 
 /**
- * Encodes an UTF-32 wide character vector into an UTF-8 multibyte character stream.
+ * Encodes an UTF-32 (TODO: 16 Bit) wide character vector into an UTF-8 multibyte character stream.
  *
  * @param p0 the destination item
  * @param p1 the source data
@@ -288,11 +291,12 @@ void encode_utf_8(void* p0, void* p1, void* p2) {
                     // anonymous state only known to the function internally is used instead.
                     // It just indicates where conversion is started.
                     int n = -1;
-                    #ifdef WIN32
-                        int len = WideCharToMultiByte (65001, 0, (LPCWSTR) sd, *sc, (LPSTR) dd, 0, NULL, NULL);
-                        n =  WideCharToMultiByte (65001, 0, (LPCWSTR) sd, *sc, (LPSTR) dd, len, NULL, NULL);
-                    #endif
-                    #ifdef GNU_LINUX_OPERATING_SYSTEM
+                    #ifdef __APPLE__
+                        n = wcsnrtombs((char*) dd, (const wchar_t**) &sd, tsc, tds, (mbstate_t*) *NULL_POINTER_STATE_CYBOI_MODEL);
+                    #elif WIN32
+                        int len = WideCharToMultiByte (CP_UTF8, 0, (LPCWSTR) sd, *sc, NULL, 0, NULL, NULL);
+                        n =  WideCharToMultiByte (CP_UTF8, 0, (LPCWSTR) sd, *sc, (LPSTR) dd, len, NULL, NULL);
+                    #elif GNU_LINUX_OPERATING_SYSTEM
                         n = wcsnrtombs((char*) dd, (const wchar_t**) &sd, tsc, tds, (mbstate_t*) *NULL_POINTER_STATE_CYBOI_MODEL);
                     #endif
 
