@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -30,10 +30,13 @@
 #include "../../../../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../../../../logger/logger.c"
 
-#ifdef WIN32
+#ifdef __APPLE__
+    //?? Add cocoa support for apple
+#elif WIN32
     #include "../../../../executor/lifeguard/sensor/win32_display/win32_display_sensor.c"
-#endif
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include "../../../../executor/lifeguard/sensor/x_window_system/x_window_system_sensor.c"
+#else
     #include "../../../../executor/lifeguard/sensor/x_window_system/x_window_system_sensor.c"
 #endif
 
@@ -48,11 +51,13 @@ void sense_display(void* p0, void* p1, void* p2) {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Sense display.");
 
-#ifdef WIN32
+#ifdef __APPLE__
+    //?? Add cocoa support for apple
+#elif WIN32
     sense_win32_display(p0, p1);
-#endif
-
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#elif GNU_LINUX_OPERATING_SYSTEM
+    sense_x_window_system(p0, p1, p2);
+#else
     sense_x_window_system(p0, p1, p2);
 #endif
 }
