@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -28,9 +28,15 @@
 
 
 #include <stdio.h>
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+
+#ifdef __APPLE__
+    #include <termios.h>
+#elif WIN32
+    //?? No import required?
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include <termios.h>
+#else
     #include <termios.h>
-/* GNU_LINUX_OPERATING_SYSTEM */
 #endif
 
 #include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
@@ -49,7 +55,9 @@
  */
 void shutdown_serial_port_attributes(void* p0, void* p1) {
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#ifdef WIN32
+    //?? WIN Support required?
+#else
     if (p0 != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
         int* d = (int*) p0;
