@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,9 +27,15 @@
 #define SERIAL_PORT_SHUTTER_SOURCE
 
 #include <stdio.h>
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#ifdef __APPLE__
     #include <termios.h>
- #endif
+#elif WIN32
+    //Not needed
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include <termios.h>
+#else
+    #include <termios.h>
+#endif
 
 #include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
 #include "../../../../constant/model/cyboi/log/message_log_cyboi_model.c"
