@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -30,13 +30,14 @@
 #include "../../../../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../../../../logger/logger.c"
 
-#ifdef DARWIN
-    #include "../../../../executor/maintainer/starter/darwin_display/darwin_display_starter.c"
-#endif
-#ifdef WIN32
+#ifdef __APPLE__
+    //#include "../../../../executor/maintainer/starter/darwin_display/darwin_display_starter.c"
+    //?? Add cocoa support for apple
+#elif WIN32
     #include "../../../../executor/maintainer/starter/win32_display/win32_display_starter.c"
-#endif
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include "../../../../executor/maintainer/starter/x_window_system/x_window_system_starter.c"
+#else
     #include "../../../../executor/maintainer/starter/x_window_system/x_window_system_starter.c"
 #endif
 
@@ -49,13 +50,14 @@ void startup_display(void* p0) {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Startup display.");
 
-#ifdef DARWIN
-    startup_darwin_display(p0);
-#endif
-#ifdef WIN32
+#ifdef __APPLE__
+    //startup_darwin_display(p0);
+    //?? Add cocoa support for apple
+#elif WIN32
     startup_win32_display(p0);
-#endif
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#elif GNU_LINUX_OPERATING_SYSTEM
+    startup_x_window_system(p0);
+#else
     startup_x_window_system(p0);
 #endif
 }
