@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -65,15 +65,20 @@
 void startup_opengl(void* p0) {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Startup opengl.");
-
-#ifdef GNU_LINUX_OPERATING_SYSTEM
-
+#ifdef __APPLE__
+    //??Check OPENGL Support for APPLE
+#elif WIN32
+    //??Check OPENGL Support for WIN32
+#elif GNU_LINUX_OPERATING_SYSTEM
+    // Startup display AT FIRST.
+    // The opengl environment needs a window
+    // to have something to paint on.
+    startup_display(p0);
+#else
     // Startup display AT FIRST.
     // The opengl environment needs a window
     // to have something to paint on.
     startup_display(p0);
-
-/* GNU_LINUX_OPERATING_SYSTEM */
 #endif
 }
 
