@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -28,13 +28,12 @@
 
 
 #include <stdio.h>
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+
+#ifdef __APPLE__
     #include <sys/ioctl.h>
     #include <termios.h>
-#endif
-#ifdef WIN32
-    // source: sys/termios.h
-
+#elif WIN32
+// source: sys/termios.h
     #define NCCS        20
 
     typedef unsigned int    tcflag_t;
@@ -52,6 +51,12 @@
     };
 
     #define TCGETA          0x5405
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include <sys/ioctl.h>
+    #include <termios.h>
+#else
+    #include <sys/ioctl.h>
+    #include <termios.h>
 #endif
 
 #include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
@@ -71,8 +76,9 @@
  * @param p2 the internal memory data
  */
 void startup_serial_port_attributes_get(void* p0, void* p1, void* p2) {
-// not ported to WIN32 at the moment ...
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#ifdef WIN32
+    //?? Port to WIN32
+#else
     if (p0 != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
         int* d = (int*) p0;
