@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,16 +19,24 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef GET_STATUS_SERIAL_PORT_STARTER_SOURCE
 #define GET_STATUS_SERIAL_PORT_STARTER_SOURCE
 
-
 #include <stdio.h>
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+
+#ifdef __APPLE__
+    #include <sys/ioctl.h>
+    #include <termios.h>
+#elif WIN32
+    //?? Add WIN32 support
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include <sys/ioctl.h>
+    #include <termios.h>
+#else
     #include <sys/ioctl.h>
     #include <termios.h>
 #endif
@@ -48,8 +56,18 @@
  * @param p0 the file descriptor data
  */
 void startup_serial_port_status_get(void* p0) {
-// not ported to WIN32 at the moment ...
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+
+#ifdef __APPLE__
+
+    //??Check support for apple - differnet librarys
+
+#elif WIN32
+
+    // not ported to WIN32 at the moment ...
+    //?? Add WIN32 support
+
+#elif GNU_LINUX_OPERATING_SYSTEM
+
     if (p0 != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
         int* d = (int*) p0;
@@ -77,6 +95,7 @@ void startup_serial_port_status_get(void* p0) {
 
         log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not startup serial port status get. The serial port file descriptor data is null.");
     }
+#else
 #endif
 }
 
