@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -29,10 +29,13 @@
 #include <fcntl.h>
 #include <stdio.h>
 
-#ifdef WIN32
+#ifdef __APPLE__
+    #include <termios.h>
+#elif WIN32
     #include <io.h>
-#endif
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include <termios.h>
+#else
     #include <termios.h>
 #endif
 
@@ -54,7 +57,7 @@
  */
 void startup_serial_port_open(void* p0, void* p1, void* p2) {
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#ifndef WIN32
     // The serial port file descriptor item.
     void* sp = *NULL_POINTER_STATE_CYBOI_MODEL;
     // The serial port file descriptor item data.
@@ -250,6 +253,7 @@ fwprintf(stdout, L"TEST open *spdi: %i\n", *spdi);
         log_message_terminated((void*) WARNING_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not startup serial port open. The serial port file descriptor item already exists.");
         fwprintf(stdout, L"%s\n", "Could not startup serial port open. The serial port file descriptor item already exists.");
     }
+//All UNIX like OS
 #endif
 }
 
