@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,23 +19,21 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef SET_ATTRIBUTES_SERIAL_PORT_STARTER_SOURCE
 #define SET_ATTRIBUTES_SERIAL_PORT_STARTER_SOURCE
 
-
 #include <stdio.h>
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+
+#ifdef __APPLE__
     #include <sys/ioctl.h>
     #include <termios.h>
-#endif
-#ifdef WIN32
+#elif WIN32
     #include <windows.h>
     // source: sys/termios.h
-
     #define IGNPAR          0000004
     #define CS8             0000060
     #define CLOCAL          0004000
@@ -43,6 +41,12 @@
     #define VMIN            6
     #define VTIME           5
     #define TCSANOW         0
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include <sys/ioctl.h>
+    #include <termios.h>
+#else
+    #include <sys/ioctl.h>
+    #include <termios.h>
 #endif
 
 #include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
@@ -62,8 +66,14 @@
  * @param p2 the baudrate
  */
 void startup_serial_port_attributes_set(void* p0, void* p1, void* p2) {
-// not ported to WIN32 at the moment ...
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+
+#ifdef __APPLE__
+    //?? Check the status for apple - maybe some problems with some librarys
+
+#elif WIN32
+    // not ported to WIN32 at the moment ...
+
+#elif GNU_LINUX_OPERATING_SYSTEM
 
     if (p0 != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
@@ -226,6 +236,7 @@ void startup_serial_port_attributes_set(void* p0, void* p1, void* p2) {
 
         log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not startup serial port attributes set. The file descriptor data is null.");
     }
+#else
 #endif
 }
 
