@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,23 +19,38 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef NAMESPACE_SOCKET_STARTER_SOURCE
 #define NAMESPACE_SOCKET_STARTER_SOURCE
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#ifdef __APPLE__
+    //?? Check support for apple
+#elif WIN32
+    //?? Add WIN32 support
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include <arpa/inet.h>
+    #include <netinet/in.h>
+    #include <sys/socket.h>
+    #include <sys/types.h>
+#ifndef _MSC_VER
+#include <unistd.h>
+#endif
+#else
+    #include <arpa/inet.h>
+    #include <netinet/in.h>
+    #include <sys/socket.h>
+    #include <sys/types.h>
+#ifndef _MSC_VER
+#include <unistd.h>
+#endif
+#endif
 
-#include <arpa/inet.h>
-#include <netinet/in.h>
-#include <sys/socket.h>
-#include <sys/types.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <stdio.h>
-#include <unistd.h>
 
 #include "../../../../constant/model/character_code/unicode/unicode_character_code_model.c"
 #include "../../../../constant/model/cybol/address_cybol_model.c"
@@ -124,8 +139,5 @@ void startup_socket_namespace(void* p0, void* p1, void* p2, void* p3) {
     }
 }
 
-/* GNU_LINUX_OPERATING_SYSTEM */
-#endif
-
 /* NAMESPACE_SOCKET_STARTER_SOURCE */
 #endif
