@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -29,14 +29,11 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "../../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
 #include "../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../executor/calculator/basic/pointer/add_pointer_calculator.c"
 #include "../../executor/calculator/basic/integer/multiply_integer_calculator.c"
+#include "../../executor/calculator/basic/pointer/add_pointer_calculator.c"
 #include "../../executor/memoriser/size_determiner.c"
-#include "../../logger/logger.c"
 
 /**
  * Adds an offset to the given pointer.
