@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -153,7 +153,7 @@ void reallocate_array(void* p0, void* p1, void* p2, void* p3) {
                             calculate_integer_multiply((void*) &nma, (void*) &es);
 
                             // The new array elements.
-                            void* na = *a + (ma - nma);
+                            void* na = (void*) ((size_t) *a + (ma - nma));
 
                             // The temporary size_t variable.
                             //
