@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -59,10 +59,15 @@ void determine_size(void* p0, void* p1) {
 
         if (*t == *DATETIME_STATE_CYBOI_TYPE) {
 
-            // CAUTION! This type IS NEEDED, e.g. when DEEP copying a part.
-            // It is actually a pointer array, of which each
-            // pointer references a structure element.
-            copy_integer(p0, (void*) POINTER_TYPE_SIZE);
+            copy_integer(p0, (void*) DATETIME_COMPOUND_TYPE_SIZE);
+
+        //
+        // duration
+        //
+
+        } else if (*t == *DURATION_STATE_CYBOI_TYPE) {
+
+            copy_integer(p0, (void*) DURATION_COMPOUND_TYPE_SIZE);
 
         //
         // element
@@ -95,10 +100,7 @@ void determine_size(void* p0, void* p1) {
 
         } else if (*t == *COMPLEX_NUMBER_STATE_CYBOI_TYPE) {
 
-            // CAUTION! This type IS NEEDED, e.g. when DEEP copying a part.
-            // It is actually a pointer array, of which each
-            // pointer references a structure element.
-            copy_integer(p0, (void*) POINTER_TYPE_SIZE);
+            copy_integer(p0, (void*) COMPLEX_COMPOUND_TYPE_SIZE);
 
         } else if (*t == *DOUBLE_NUMBER_STATE_CYBOI_TYPE) {
 
@@ -106,10 +108,7 @@ void determine_size(void* p0, void* p1) {
 
         } else if (*t == *FRACTION_NUMBER_STATE_CYBOI_TYPE) {
 
-            // CAUTION! This type IS NEEDED, e.g. when DEEP copying a part.
-            // It is actually a pointer array, of which each
-            // pointer references a structure element.
-            copy_integer(p0, (void*) POINTER_TYPE_SIZE);
+            copy_integer(p0, (void*) FRACTION_COMPOUND_TYPE_SIZE);
 
         } else if (*t == *INTEGER_NUMBER_STATE_CYBOI_TYPE) {
 
