@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,8 +27,7 @@
 #define COMMAND_LINE_DESERIALISER_SOURCE
 
 #ifdef WIN32
-#include <windows.h>
-/* WIN32_ENVIRONMENT */
+    #include <windows.h>
 #endif
 
 #include <stdio.h>
@@ -52,7 +51,11 @@
  * Therefore, this function checks for these two command line argument options.
  *
  * A further option that was added is '--test'. It is just to ease cyboi
- * development because that way, programmers can easily call test functions.
+ * development because that way, programmers can easily call test functions
+ * by specifying a special test unit, e.g.:
+ * - all
+ * - calculator
+ * - comparator
  *
  * The standard option used to run cybol applications is '--knowledge'.
  * Behind it, the cybol file name needs to be given as argument.
@@ -81,11 +84,12 @@
  * @param p0 the operation mode
  * @param p1 the cybol knowledge file path item
  * @param p2 the log level
- * @param p3 the terminated log file name item (multibyte character data)
- * @param p4 the command line data (pointer reference)
- * @param p5 the command line count
+ * @param p3 the test unit
+ * @param p4 the terminated log file name item (multibyte character data)
+ * @param p5 the command line data (pointer reference)
+ * @param p6 the command line count
  */
-void deserialise_command_line(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5) {
+void deserialise_command_line(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6) {
 
     // CAUTION! DO NOT use logging functionality here!
     // The logger will not work before its options are set.
@@ -100,7 +104,7 @@ void deserialise_command_line(void* p0, void* p1, void* p2, void* p3, void* p4,
     // The break flag.
     int b = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
 
-    if (p5 == *NULL_POINTER_STATE_CYBOI_MODEL) {
+    if (p6 == *NULL_POINTER_STATE_CYBOI_MODEL) {
 
         // CAUTION! If the loop count handed over as parametre is NULL,
         // then the break flag will NEVER be set to true, because the loop
@@ -114,14 +118,14 @@ void deserialise_command_line(void* p0, void* p1, void* p2, void* p3, void* p4,
 
     while (*TRUE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        compare_integer_greater_or_equal((void*) &b, (void*) &j, p5);
+        compare_integer_greater_or_equal((void*) &b, (void*) &j, p6);
 
         if (b != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
             break;
         }
 
-        deserialise_command_line_argument(p0, p1, p2, p3, p4, (void*) &j);
+        deserialise_command_line_argument(p0, p1, p2, p3, p4, p5, (void*) &j);
 
         // Increment loop variable.
         j++;
