@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,8 +27,7 @@
 #define OPTION_COMMAND_LINE_DESERIALISER_SOURCE
 
 #ifdef WIN32
-#include <windows.h>
-/* WIN32_ENVIRONMENT */
+    #include <windows.h>
 #endif
 
 #include <stdio.h>
@@ -49,11 +48,12 @@
  * @param p0 the operation mode
  * @param p1 the cybol knowledge file path item
  * @param p2 the log level
- * @param p3 the terminated log file name item (multibyte character data)
- * @param p4 the argument data (pointer reference)
- * @param p5 the argument count
+ * @param p3 the test unit
+ * @param p4 the terminated log file name item (multibyte character data)
+ * @param p5 the argument data (pointer reference)
+ * @param p6 the argument count
  */
-void deserialise_command_line_option(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5) {
+void deserialise_command_line_option(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6) {
 
     // CAUTION! DO NOT use logging functionality here!
     // The logger will not work before its options are set.
@@ -70,9 +70,9 @@ void deserialise_command_line_option(void* p0, void* p1, void* p2, void* p3, voi
     int b = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
 
     // Initialise option data.
-    copy_pointer((void*) &od, p4);
+    copy_pointer((void*) &od, p5);
 
-    if (p5 == *NULL_POINTER_STATE_CYBOI_MODEL) {
+    if (p6 == *NULL_POINTER_STATE_CYBOI_MODEL) {
 
         // CAUTION! If the loop count handed over as parametre is NULL,
         // then the break flag will NEVER be set to true, because the loop
@@ -86,7 +86,7 @@ void deserialise_command_line_option(void* p0, void* p1, void* p2, void* p3, voi
 
     while (*TRUE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        compare_integer_smaller_or_equal((void*) &b, p5, (void*) NUMBER_0_INTEGER_STATE_CYBOI_MODEL);
+        compare_integer_smaller_or_equal((void*) &b, p6, (void*) NUMBER_0_INTEGER_STATE_CYBOI_MODEL);
 
         if (b != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
@@ -97,7 +97,7 @@ void deserialise_command_line_option(void* p0, void* p1, void* p2, void* p3, voi
             break;
         }
 
-        select_command_line_option((void*) &b, p4, p5);
+        select_command_line_option((void*) &b, p5, p6);
 
         if (b != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
@@ -105,8 +105,8 @@ void deserialise_command_line_option(void* p0, void* p1, void* p2, void* p3, voi
             // All data following belong to the value.
 
             // Initialise value data, count.
-            copy_pointer((void*) &vd, p4);
-            copy_integer((void*) &vc, p5);
+            copy_pointer((void*) &vd, p5);
+            copy_integer((void*) &vc, p6);
 
             break;
 
@@ -120,7 +120,7 @@ void deserialise_command_line_option(void* p0, void* p1, void* p2, void* p3, voi
     // Not all options require a value.
     // But the option has to be processed here anyway,
     // even if no separator was found, i.e. no value was given.
-    select_command_line_mode(p0, p1, p2, p3, vd, (void*) &vc, od, (void*) &oc);
+    select_command_line_mode(p0, p1, p2, p3, p4, vd, (void*) &vc, od, (void*) &oc);
 }
 
 /* OPTION_COMMAND_LINE_DESERIALISER_SOURCE */
