@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,17 +19,13 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef VALUE_INTEGER_CYBOL_SERIALISER_SOURCE
 #define VALUE_INTEGER_CYBOL_SERIALISER_SOURCE
 
-#ifdef WIN32
-    #include <windows.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <wchar.h>
