@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -61,8 +61,11 @@ void serialise_html_begin_tag(void* p0, void* p1, void* p2, void* p3, void* p4,
     // Append html tag properties.
     serialise_html_attributes(p0, p3, p4);
 
+    // Initialise comparison result.
+    logify_boolean_or((void*) &r, p5);
+
     // Check if content is empty AND element is allowed to be void.
-    logify_boolean_and((void*) &r, p5, p6);
+    logify_boolean_and((void*) &r, p6);
 
     if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
