@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -59,7 +59,8 @@ void serialise_tui_character(void* p0, void* p1, void* p2, void* p3, void* p4, v
 
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        logify_boolean_and((void*) &r, p7, p10);
+        logify_boolean_or((void*) &r, p7);
+        logify_boolean_and((void*) &r, p10);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
@@ -67,9 +68,13 @@ void serialise_tui_character(void* p0, void* p1, void* p2, void* p3, void* p4, v
         }
     }
 
+    // Reset comparison result.
+    r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
+
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        logify_boolean_and((void*) &r, p9, p10);
+        logify_boolean_or((void*) &r, p9);
+        logify_boolean_and((void*) &r, p10);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
@@ -77,9 +82,13 @@ void serialise_tui_character(void* p0, void* p1, void* p2, void* p3, void* p4, v
         }
     }
 
+    // Reset comparison result.
+    r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
+
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        logify_boolean_and((void*) &r, p8, p10);
+        logify_boolean_or((void*) &r, p8);
+        logify_boolean_and((void*) &r, p10);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
@@ -87,9 +96,13 @@ void serialise_tui_character(void* p0, void* p1, void* p2, void* p3, void* p4, v
         }
     }
 
+    // Reset comparison result.
+    r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
+
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        logify_boolean_and((void*) &r, p7, p12);
+        logify_boolean_or((void*) &r, p7);
+        logify_boolean_and((void*) &r, p12);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
@@ -97,9 +110,13 @@ void serialise_tui_character(void* p0, void* p1, void* p2, void* p3, void* p4, v
         }
     }
 
+    // Reset comparison result.
+    r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
+
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        logify_boolean_and((void*) &r, p9, p12);
+        logify_boolean_or((void*) &r, p9);
+        logify_boolean_and((void*) &r, p12);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
@@ -107,9 +124,13 @@ void serialise_tui_character(void* p0, void* p1, void* p2, void* p3, void* p4, v
         }
     }
 
+    // Reset comparison result.
+    r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
+
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        logify_boolean_and((void*) &r, p8, p12);
+        logify_boolean_or((void*) &r, p8);
+        logify_boolean_and((void*) &r, p12);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
@@ -117,9 +138,13 @@ void serialise_tui_character(void* p0, void* p1, void* p2, void* p3, void* p4, v
         }
     }
 
+    // Reset comparison result.
+    r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
+
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        logify_boolean_and((void*) &r, p7, p11);
+        logify_boolean_or((void*) &r, p7);
+        logify_boolean_and((void*) &r, p11);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
@@ -127,9 +152,13 @@ void serialise_tui_character(void* p0, void* p1, void* p2, void* p3, void* p4, v
         }
     }
 
+    // Reset comparison result.
+    r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
+
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        logify_boolean_and((void*) &r, p9, p11);
+        logify_boolean_or((void*) &r, p9);
+        logify_boolean_and((void*) &r, p11);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
@@ -137,9 +166,13 @@ void serialise_tui_character(void* p0, void* p1, void* p2, void* p3, void* p4, v
         }
     }
 
+    // Reset comparison result.
+    r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
+
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        logify_boolean_and((void*) &r, p8, p11);
+        logify_boolean_or((void*) &r, p8);
+        logify_boolean_and((void*) &r, p11);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
