@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -36,15 +36,22 @@
 #include "../../../../executor/representer/serialiser/tui/horizontal_position_tui_serialiser.c"
 #include "../../../../logger/logger.c"
 
-#ifdef WIN32
+
+#ifdef __APPLE__
+    #include "../../../../executor/representer/serialiser/ansi_escape_code/character_ansi_escape_code_serialiser.c"
+    #include "../../../../executor/representer/serialiser/ansi_escape_code/position_ansi_escape_code_serialiser.c"
+#elif WIN32
     #include "../../../../executor/representer/serialiser/win32_console/character_win32_console_serialiser.c"
     #include "../../../../executor/representer/serialiser/win32_console/position_win32_console_serialiser.c"
-#endif
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include "../../../../executor/representer/serialiser/ansi_escape_code/character_ansi_escape_code_serialiser.c"
+    #include "../../../../executor/representer/serialiser/ansi_escape_code/position_ansi_escape_code_serialiser.c"
+#else
     #include "../../../../executor/representer/serialiser/ansi_escape_code/character_ansi_escape_code_serialiser.c"
     #include "../../../../executor/representer/serialiser/ansi_escape_code/position_ansi_escape_code_serialiser.c"
 #endif
 
+
 /**
  * Serialises the row into tui.
  *
@@ -112,22 +119,27 @@ void serialise_tui_row(void* p0, void* p1, void* p2, void* p3, void* p4, void* p
 
         // Determine horizontal position of x coordinate.
         serialise_tui_position_horizontal((void*) &lp, (void*) &cp, (void*) &rp, (void*) &x, (void*) &li, (void*) &ri);
-
-#ifdef WIN32
-        serialise_win32_console_position(p1, (void*) &x, p10);
-#endif
-#ifdef GNU_LINUX_OPERATING_SYSTEM
-        serialise_ansi_escape_code_position(p0, (void*) &x, p10);
-#endif
-
+        #ifdef __APPLE__
+            serialise_ansi_escape_code_position(p0, (void*) &x, p10);
+        #elif WIN32
+            serialise_win32_console_position(p1, (void*) &x, p10);
+        #elif GNU_LINUX_OPERATING_SYSTEM
+            serialise_ansi_escape_code_position(p0, (void*) &x, p10);
+        #else
+            serialise_ansi_escape_code_position(p0, (void*) &x, p10);
+        #endif
+        
         serialise_tui_character((void*) &ch, p2, p3, p4, p5, p6, p7, (void*) &lp, (void*) &cp, (void*) &rp, p11, p12, p13);
 
-#ifdef WIN32
-        serialise_win32_console_character(p1, (void*) &ch, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT);
-#endif
-#ifdef GNU_LINUX_OPERATING_SYSTEM
-        serialise_ansi_escape_code_character(p0, (void*) &ch, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT);
-#endif
+        #ifdef __APPLE__
+            serialise_ansi_escape_code_character(p0, (void*) &ch, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT);
+        #elif WIN32
+            serialise_win32_console_character(p1, (void*) &ch, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT);
+        #elif GNU_LINUX_OPERATING_SYSTEM
+            serialise_ansi_escape_code_character(p0, (void*) &ch, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT);
+        #else
+            serialise_ansi_escape_code_character(p0, (void*) &ch, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT);
+        #endif
 
         // Increment loop variable.
         x++;
