@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -28,14 +28,19 @@
 
 #include <errno.h>
 #include <time.h>
-#include <unistd.h>
+
+#ifdef _MSC_VER
+    #include "../../windows/cyboi_win_mapper.h"
+#else
+    #include <unistd.h>
+    #ifdef WIN32
+        #include <pthread_time.h>
+    #endif
+#endif
 
 #include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 #include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
 
-#ifdef WIN32
-    #include <pthread_time.h>
-#endif
 
 /**
  * Suspends execution of the calling thread for (at least)
