@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,8 +27,23 @@
 #define DISPLAY_TESTER
 
 #ifdef WIN32
-    #include <winsock2.h>
+#ifndef _MSC_VER
+#define INCLUDE_WINSOCK2
 #endif
+#endif
+
+#ifdef WIN32_LEAN_AND_MEAN
+#ifdef _MSC_VER
+#define INCLUDE_WINSOCK2
+#endif
+#endif
+
+#ifdef WIN32
+#ifdef INCLUDE_WINSOCK2
+#include <winsock2.h>
+#endif
+#endif
+
 #include <xcb/xcb.h>
 #ifdef WIN32
     int initWSA(void);
@@ -68,8 +83,10 @@ void test_display_drawing() {
     xcb_arc_t arcs[] = {
         { 10, 100, 60, 40, 0, 90 << 6 },
         { 90, 100, 55, 40, 0, 270 << 6 }};
-
-#ifdef WIN32
+    
+#ifdef __APPLE__
+    //?? TODO: Add support for Cocoa
+#elif WIN32
     int screenNum,i;
     int rc;
 
@@ -95,8 +112,12 @@ void test_display_drawing() {
     }
 
     xcb_screen_t *screen = iter.data;
-#endif
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#elif GNU_LINUX_OPERATING_SYSTEM
+    // Open connection to x server.
+    xcb_connection_t* connection = xcb_connect(NULL, NULL);
+    // Get first screen.
+    xcb_screen_t* screen = xcb_setup_roots_iterator(xcb_get_setup(connection)).data;
+#else
     // Open connection to x server.
     xcb_connection_t* connection = xcb_connect(NULL, NULL);
     // Get first screen.
