@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -35,15 +35,17 @@ void test_preprocessor_directives() {
 
     log_write((void*) stdout, L"Test preprocessor directives:\n");
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
-    log_write((void*) stdout, L"GNU_LINUX\n");
-#elif WINDOWS_OPERATING_SYSTEM
-    log_write((void*) stdout, L"WINDOWS\n");
+    
+#ifdef __APPLE__
+    log_write((void*) stdout, L"MAC OS X\n");
 #elif WIN32
     log_write((void*) stdout, L"WIN32\n");
+#elif WINDOWS_OPERATING_SYSTEM
+    log_write((void*) stdout, L"WINDOWS\n");
+#elif GNU_LINUX_OPERATING_SYSTEM
+    log_write((void*) stdout, L"GNU_LINUX\n");
 #else
     log_write((void*) stdout, L"OTHER\n");
-/* GNU_LINUX_OPERATING_SYSTEM */
 #endif
 }
 
@@ -55,9 +57,9 @@ void test_preprocessor_directives() {
  */
 void test_preprocessor() {
 
-//    fwprintf(stdout, L"TEST preprocessor.\n");
+    fwprintf(stdout, L"TEST preprocessor.\n");
 
-//    test_preprocessor_directives();
+    test_preprocessor_directives();
 }
 
 /* PREPROCESSOR_TESTER */
