@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2014. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.16.0 2014-03-31
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -131,9 +131,9 @@ void test_referencer_part() {
  */
 void test_referencer() {
 
-//    fwprintf(stdout, L"TEST referencer.\n");
+    fwprintf(stdout, L"TEST referencer.\n");
 
-//    test_referencer_part();
+    test_referencer_part();
 }
 
 /* REFERENCER_TESTER */
